==> eagle-i-repository-webapp-1.0-MS6.08-sources.jar: jsp/repository/version/index_jsp.java <==
package jsp.repository.version;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.eaglei.repository.DataRepository;

public final class index_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD XHTML+RDFa 1.0//EN\" \"http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\"\n      xmlns:dc=\"http://purl.org/dc/elements/1.1/\"\n      lang=\"en\"\n      xml:lang=\"en\">\n");
      out.write('\n');
      out.write('\n');

    String mavenVersion = DataRepository.getInstance().getProjectVersion();
    String buildTime = DataRepository.getInstance().getTimestamp();
    String scmVersion = DataRepository.getInstance().getRevision();
    String scmBranch = DataRepository.getInstance().getBranch();
    String about = request.getRequestURL().toString();
 
      out.write("\n  <head about=\"");
      out.print( about );
      out.write("\">\n    <meta property=\"dc:description\" content=\"");
      out.print( mavenVersion );
      out.write("\" />\n    <meta property=\"dc:date\" content=\"");
      out.print( buildTime );
      out.write("\" />\n    <meta property=\"dc:source\" content=\"");
      out.print( scmVersion );
      out.write("\" />\n    <title>Eagle-I Repository Version</title>\n  </head>\n  <body about=\"");
      out.print( about );
      out.write("\">\n    <h1>Eagle-i Data Repository Version Information</h1>\n    <dl>\n      <dt>Maven package version</dt>\n      <dd><tt property=\"dc:description\">");
      out.print( mavenVersion );
      out.write("</tt></dd>\n      <dt>Build time</dt>\n      <dd><tt property=\"dc:date\">");
      out.print( buildTime );
      out.write("</tt></dd>\n      <dt>SCM Branch</dt>\n      <dd><tt property=\"dc:source\">");
      out.print( scmBranch == null ? "trunk" : scmBranch );
      out.write("</tt></dd>\n      <dt>SCM revision</dt>\n      <dd><tt property=\"dc:source\">");
      out.print( scmVersion );
      out.write("</tt></dd>\n    </dl>\n  </body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.1-MS5.01-sources.jar: jsp/repository/version/index_jsp.java <==
package jsp.repository.version;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.apache.commons.lang.StringEscapeUtils;
import org.eaglei.repository.DataRepository;
import org.eaglei.repository.util.Utils;

public final class index_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n<!DOCTYPE HTML PUBLIC \"-//W3C//DTD XHTML+RDFa 1.0//EN\" \"http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\"\n      xmlns:dc=\"http://purl.org/dc/elements/1.1/\"\n      lang=\"en\"\n      xml:lang=\"en\">\n");
      out.write("\n\n\n\n");

    String mavenVersion = DataRepository.getInstance().getProjectVersion();
    String buildTime = DataRepository.getInstance().getTimestamp();
    String scmVersion = DataRepository.getInstance().getRevision();
    String scmBranch = DataRepository.getInstance().getBranch();
    String about = request.getRequestURL().toString();
    String sesameVersion = DataRepository.getInstance().getSesameVersion();
 
      out.write("\n  <head about=\"");
      out.print( Utils.escapeHTMLAttribute(about) );
      out.write("\">\n    <meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"/>\n    <meta property=\"dc:description\" content=\"");
      out.print( Utils.escapeHTMLAttribute(mavenVersion) );
      out.write("\" />\n    <meta property=\"dc:date\" content=\"");
      out.print( Utils.escapeHTMLAttribute(buildTime) );
      out.write("\" />\n    <meta property=\"dc:source\" content=\"");
      out.print( Utils.escapeHTMLAttribute(scmVersion) );
      out.write("\" />\n    <title>Eagle-I Repository Version</title>\n  </head>\n  <body about=\"");
      out.print( Utils.escapeHTMLAttribute(about) );
      out.write("\">\n    <h1>Eagle-i Data Repository Version Information</h1>\n    <dl>\n      <dt>Maven package version</dt>\n      <dd><tt property=\"dc:description\">");
      out.print( StringEscapeUtils.escapeHtml(mavenVersion) );
      out.write("</tt></dd>\n      <dt>Build time</dt>\n      <dd><tt property=\"dc:date\">");
      out.print( StringEscapeUtils.escapeHtml(buildTime) );
      out.write("</tt></dd>\n      <dt>SCM Branch</dt>\n      <dd><tt property=\"dc:source\">");
      out.print( scmBranch == null ? "trunk" : StringEscapeUtils.escapeHtml(scmBranch) );
      out.write("</tt></dd>\n      <dt>SCM revision</dt>\n      <dd><tt property=\"dc:source\">");
      out.print( StringEscapeUtils.escapeHtml(scmVersion) );
      out.write("</tt></dd>\n      <dt>OpenRDF Sesame Version</dt>\n      <dd><tt property=\"dc:source\">");
      out.print( sesameVersion );
      out.write("</tt></dd>\n    </dl>\n  </body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
